declare type State = {
    result?: unknown;
    error?: 'error' | 'messageerror';
};
/**
 * use worker
 *
 * The createWorker function should be stable to keep the worker running.
 * If it's referentially changed, it will create a new worker and terminate the old one.
 *
 * @example
 *
 * import { useWorker } from 'react-hooks-worker';
 *
 * const createWorker = () => new Worker('./slow_fib.worker', { type: 'module' });
 *
 * const CalcFib = ({ count }) => {
 *   const { result, error } = useWorker(createWorker, count);
 *   if (error) return <div>Error: {error}</div>;
 *   return <div>Result: {result}</div>;
 * };
 */
export declare function useWorker(createWorker: () => Worker, input: unknown): State;
export {};
